pub struct SplitArgs<'a> {
pub account_id: [u8; 16],
pub commodity_id: [u8; 16],
pub value_num: i64,
pub value_denom: i64,
pub reconcile_state: u8,
pub reconcile_date: i64,
pub account_name: &'a str,
}Expand description
Body fields specific to a split entity. account_name borrows from the
caller and is interned into the strings pool by
MemorySerializer::add_split so a trigger script can read the posting
account’s display name via SPLIT-ACCOUNT-NAME.
Fields
account_id: [u8; 16]commodity_id: [u8; 16]value_num: i64value_denom: i64reconcile_state: u8reconcile_date: i64account_name: &'a strTrait Implementations
impl<'a> Copy for SplitArgs<'a>